/**
 * Validates the provided data or throws an error
 * @param typeName {string} The data type to validate
 * @param data {object} The data to validate
 * @returns {boolean} True if valid, throws if invalid
 */
export declare const validate: (typeName: string, data: unknown) => boolean;
/**
 * Determine if the provided value is an object or a primitive type
 * @param value The data
 * @returns {boolean} True if the provided value is an object
 */
export declare const isObject: (value: unknown) => boolean;
/**
 * Represents the options used to convert string to pascal case or camel case
 */
export interface CaseConvertionOptions {
    /** Keep dashes (-) characters */
    keepDashes: boolean;
    /** Capitalize after dashes (-) characters, if kept */
    capitalizeAfterDashes: boolean;
    /** Keep underscores (_) characters */
    keepUnderscores: boolean;
    /** Capitalize after underscores (_) characters, if kept */
    capitalizeAfterUnderscores: boolean;
    /** Keep dots (.) characters */
    keepDots: boolean;
    /** Capitalize after dots (.) characters, if kept */
    capitalizeAfterDots: boolean;
}
/**
 * Holds default convertion options
 */
export declare const defaultConvertionOptions: CaseConvertionOptions;
/**
 * Converts a string to pascal case (PascalCase)
 * @param source string The string to convert to pascal case
 * @param convertionOptions CaseConvertionOptions Defaults: keepDashes: false, capitalizeAfterDashes: false, keepUnderscores: false, capitalizeAfterUnderscores: false, keepDots: true, capitalizeAfterDots: true
 * @returns string The pascal case string
 */
export declare const pascalCase: (source: string, convertionOptions?: CaseConvertionOptions) => string;
/**
 * Converts a PasalCase/camelCase string into a human readable string
 * @param source string The string to convert
 * @param keepCapitalLetters boolean If capital letters should be kept
 * @returns string The converted string
 */
export declare const humanCase: (source: string, keepCapitalLetters?: boolean) => string;
//# sourceMappingURL=utils.d.ts.map